==========
tomography
==========

.. image:: https://github.com/st3107/tomology/actions/workflows/test.yml/badge.svg
        :target: https://github.com/st3107/tomology/actions/workflows/test.yml

.. image:: https://codecov.io/gh/st3107/tomology/branch/main/graph/badge.svg?token=GLRRK9K9BM
      :target: https://codecov.io/gh/st3107/tomology


Obtain the distribution of grains inside a crystal from a series of diffraction images using automated peak
tracking.

* Free software: 3-clause BSD license
* Documentation: https://st3107.github.io/tomography.
